==> com.liferay.journal.web-3.0.48.jar: META-INF/resources/js/ChangeDefaultLanguage.es.js <==
Liferay.Loader.define("journal-web@3.0.48/js/ChangeDefaultLanguage.es", ['module', 'exports', 'require', 'frontend-taglib-clay$clay-dropdown', 'frontend-taglib-clay$clay-label', 'frontend-js-metal-web$metal', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './ChangeDefaultLanguage.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  require("frontend-taglib-clay$clay-dropdown");

  require("frontend-taglib-clay$clay-label");

  require("frontend-js-metal-web$metal");

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _ChangeDefaultLanguage = _interopRequireDefault(require("./ChangeDefaultLanguage.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(source, true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(source).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * ChangeDefaultLanguage
   */
  var ChangeDefaultLanguage =
  /*#__PURE__*/
  function (_Component) {
    _inherits(ChangeDefaultLanguage, _Component);

    function ChangeDefaultLanguage() {
      _classCallCheck(this, ChangeDefaultLanguage);

      return _possibleConstructorReturn(this, _getPrototypeOf(ChangeDefaultLanguage).apply(this, arguments));
    }

    _createClass(ChangeDefaultLanguage, [{
      key: "_itemClicked",
      value: function _itemClicked(event) {
        var defaultLanguage = event.data.item.label;
        this.defaultLanguage = defaultLanguage;
        this.languages = this.languages.map(function (language) {
          return _objectSpread({}, language, {
            checked: language.label === defaultLanguage
          });
        });
        var dropdown = event.target.refs.dropdown.refs.portal.element;
        var item = dropdown.querySelector("li[data-value=\"".concat(defaultLanguage, "\"]"));
        Liferay.fire('inputLocalized:defaultLocaleChanged', {
          item: item
        });
      }
    }]);

    return ChangeDefaultLanguage;
  }(_metalComponent["default"]);

  _metalSoy["default"].register(ChangeDefaultLanguage, _ChangeDefaultLanguage["default"]);

  var _default = ChangeDefaultLanguage;
  exports["default"] = _default;
  //# sourceMappingURL=ChangeDefaultLanguage.es.js.map
});
//# sourceMappingURL=ChangeDefaultLanguage.es.js.map

==> com.liferay.journal.web-3.0.105.jar: META-INF/resources/js/ChangeDefaultLanguage.es.js <==
Liferay.Loader.define("journal-web@3.0.105/js/ChangeDefaultLanguage.es", ['module', 'exports', 'require', 'frontend-taglib-clay$clay-dropdown', 'frontend-taglib-clay$clay-label', 'frontend-js-metal-web$metal', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './ChangeDefaultLanguage.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  require("frontend-taglib-clay$clay-dropdown");

  require("frontend-taglib-clay$clay-label");

  require("frontend-js-metal-web$metal");

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _ChangeDefaultLanguage = _interopRequireDefault(require("./ChangeDefaultLanguage.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * ChangeDefaultLanguage
   */
  var ChangeDefaultLanguage = /*#__PURE__*/function (_Component) {
    _inherits(ChangeDefaultLanguage, _Component);

    function ChangeDefaultLanguage() {
      _classCallCheck(this, ChangeDefaultLanguage);

      return _possibleConstructorReturn(this, _getPrototypeOf(ChangeDefaultLanguage).apply(this, arguments));
    }

    _createClass(ChangeDefaultLanguage, [{
      key: "_itemClicked",
      value: function _itemClicked(event) {
        var defaultLanguage = event.data.item.label;
        this.defaultLanguage = defaultLanguage;
        this.languages = this.languages.map(function (language) {
          return _objectSpread({}, language, {
            checked: language.label === defaultLanguage
          });
        });
        var dropdown = event.target.refs.dropdown.refs.portal.element;
        var item = dropdown.querySelector("li[data-value=\"".concat(defaultLanguage, "\"]"));
        Liferay.fire('inputLocalized:defaultLocaleChanged', {
          item: item
        });
      }
    }]);

    return ChangeDefaultLanguage;
  }(_metalComponent["default"]);

  _metalSoy["default"].register(ChangeDefaultLanguage, _ChangeDefaultLanguage["default"]);

  var _default = ChangeDefaultLanguage;
  exports["default"] = _default;
  //# sourceMappingURL=ChangeDefaultLanguage.es.js.map
});
//# sourceMappingURL=ChangeDefaultLanguage.es.js.map
